import math
import random

class RandomCoord:
  def __init__(self, lng, lat):
    self.lng = lng
    self.lat = lat

  def randomize_coords(self):
    #Earth’s radius, sphere
    R=6378137

    # offsets in meters
    dn = random.randint(5,25)
    de = random.randint(5,25)

    #Coordinate offsets in radians
    dLat = dn/R
    dLng = de/(R*math.cos(math.pi*self.lat/180))

    #OffsetPosition, decimal degrees
    latO = self.lat + dLat * 180/math.pi
    lngO = self.lng + dLng * 180/math.pi

    self.lng=lngO
    self.lat=latO
    return self



import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name="cluster_coords", # Replace with your own username
    version="0.0.1",
    author="Sonny Parlin",
    author_email="ask@sparl.in",
    description=("Build cluster from multiple identical longitude and latitude coordinates"),
    license = "MIT",
    long_description=read('README.md'),
    long_description_content_type="text/markdown",
    url="https://github.com/sonnyparlin/cluster_coords/",
    project_urls={
        "Bug Tracker": "https://github.com/sonnyparlin/cluster_coords/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(),
    python_requires='>=3.6',
)
